@@ -5,4 +5,4 @@ autoheader --force
 automake --add-missing --gnu  --force-missing
 autoconf
 
-./configure --datadir=/usr/share
+./configure --datadir=/usr/share --prefix=/usr
